Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Group ¶
Stopper extends sync.WaitGroup to add a convenient way to stop running goroutines
func New ¶
New allocates and returns a new instance. Use New(parent) to create an instance that is stopped when parent is stopped.
func (*Group) Stop ¶
func (s *Group) Stop()
Stop signals any listening processes to stop. After the first call, Stop() does nothing.
func (*Group) StopAndWait ¶
func (s *Group) StopAndWait()
StopAndWait is a convenience method to close the channel and wait for goroutines to return.
Click to show internal directories.
Click to hide internal directories.